==> visailu-2023.8.25.tar.gz: visailu-2023.8.25/README.md <==
# Visailu 

Quiz (Finnish: visailu) data operations.

[License: MIT](https://git.sr.ht/~sthagen/visailu/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/visailu.svg?style=flat)](https://pypi.python.org/pypi/visailu/)
[![downloads](https://pepy.tech/badge/visailu/month)](https://pepy.tech/project/visailu)
[![wheel](https://img.shields.io/pypi/wheel/visailu.svg?style=flat)](https://pypi.python.org/pypi/visailu/)
[![supported-versions](https://img.shields.io/pypi/pyversions/visailu.svg?style=flat)](https://pypi.python.org/pypi/visailu/)
[![supported-implementations](https://img.shields.io/pypi/implementation/visailu.svg?style=flat)](https://pypi.python.org/pypi/visailu/)
[![maintenance-status](https://img.shields.io/github/commit-activity/y/sthagen/visailu.svg?style=flat)](https://git.sr.ht/~sthagen/visailu/log)

## Documentation

User and developer [documentation of visailu](https://codes.dilettant.life/docs/visailu).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of visailu](https://todo.sr.ht/~sthagen/visailu).

## Primary Source repository

The main source of `visailu` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `visailu` are:

* [on codeberg](https://codeberg.org/sthagen/visailu) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/visailu) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

# Status

Experimental.

**Note** The default branch is `default`.

==> visailu-2023.8.27.tar.gz: visailu-2023.8.27/README.md <==
# Visailu 

Quiz (Finnish: visailu) data operations.

[License: MIT](https://git.sr.ht/~sthagen/visailu/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](docs/third-party/README.md).

[![version](https://img.shields.io/pypi/v/visailu.svg?style=flat)](https://pypi.python.org/pypi/visailu/)
[![downloads](https://static.pepy.tech/badge/visailu/month)](https://pepy.tech/project/visailu)
[![wheel](https://img.shields.io/pypi/wheel/visailu.svg?style=flat)](https://pypi.python.org/pypi/visailu/)
[![supported-versions](https://img.shields.io/pypi/pyversions/visailu.svg?style=flat)](https://pypi.python.org/pypi/visailu/)
[![supported-implementations](https://img.shields.io/pypi/implementation/visailu.svg?style=flat)](https://pypi.python.org/pypi/visailu/)
[![maintenance-status](https://img.shields.io/github/commit-activity/y/sthagen/visailu.svg?style=flat)](https://git.sr.ht/~sthagen/visailu/log)

## Documentation

User and developer [documentation of visailu](https://codes.dilettant.life/docs/visailu).

## Bug Tracker

Any feature requests or bug reports shall go to the [todos of visailu](https://todo.sr.ht/~sthagen/visailu).

## Primary Source repository

The main source of `visailu` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `visailu` are:

* [on codeberg](https://codeberg.org/sthagen/visailu) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/visailu) - a collection of tools useful for software development.

## Contributions

Please do not submit "pull requests" (I found no way to disable that "feature" on GitHub).
If you like to share small changes under the repositories license please kindly do so by sending a patchset.
You can either send such a patchset per email using [git send-email](https://git-send-email.io) or
if you are a sourcehut user by selecting "Prepare a patchset" on the summary page of your fork at [sourcehut](https://git.sr.ht/).

# Status

Experimental.

**Note** The default branch is `default`.
